@@ -20,6 +20,7 @@ class dbmysql:
                  user: str,
                  password: str,
                  database: str,
+                 autocommit: bool = True,
                  loop: asyncio.AbstractEventLoop = None):
         self.conn = None
         self.host = host
@@ -27,6 +28,7 @@ class dbmysql:
         self.user = user
         self.password = password
         self.database = database
+        self.autocommit = autocommit
         self.loop = loop or asyncio.get_event_loop()
 
         # 权限，自动提交检测时间
@@ -45,7 +47,8 @@ class dbmysql:
 
         self.connect()
         
-        self.__periodic_check()
+        if not autocommit:
+            self.__periodic_check()
 
     def __make_where(self, col_names: list, where: dict, inject: str = None):
         where_str = ""
@@ -165,7 +168,8 @@ class dbmysql:
             user=self.user,
             password=self.password,
             database=self.database,
-            charset='utf8'
+            charset='utf8',
+            autocommit=self.autocommit
         )
         self.flush_tables_cache()
 
@@ -237,6 +241,7 @@ class dbmysql:
                 if len(ret) <= 0:
                     ret = None
             cursor.close()
+            self.__need_commit = True
             return ret
         except Exception as e:
             logging.error(f"db get error {e.with_traceback(None)}")
